@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.68';
+$Test::BDD::Cucumber::Parser::VERSION = '0.69';
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.68
+version 0.69
 
 =head1 DESCRIPTION
 
@@ -240,7 +240,7 @@ sub _finish_scenario {
     if ( @{ $feature->scenarios } ) {
         my $last_scenario = $feature->scenarios->[-1];
         if ( $last_scenario->keyword_original =~ m/^($self->{langdef}->{scenarioOutline})/
-             && !@{ $last_scenario->data } )
+             && !@{ $last_scenario->datasets } )
         {
             die parse_error_from_line(
                 "Outline scenario expects 'Examples:' section",
@@ -274,6 +274,10 @@ sub _extract_scenarios {
                 line => $line,
                 );
             @tags = ();
+            @lines = $self->_extract_examples_description( $dataset, @lines );
+            @lines = $self->_extract_table( 6, $dataset,
+                                            $self->_remove_next_blanks(@lines) );
+
             if (@{$feature->scenarios->[-1]->datasets}) {
                 my $prev_ds = $feature->scenarios->[-1]->datasets->[0];
                 my $prev_ds_cols = join '|', keys %{$prev_ds->data->[0]};
@@ -286,9 +290,6 @@ sub _extract_scenarios {
             }
             push @{$feature->scenarios->[-1]->datasets}, $dataset;
 
-            @lines = $self->_extract_examples_description( $dataset, @lines );
-            @lines = $self->_extract_table( 6, $dataset,
-                                            $self->_remove_next_blanks(@lines) );
         }
         elsif ( ( $type, $name ) =
                 $self->_is_scenario_line( $line->content ) ) {
